@@ -240,10 +240,9 @@ anjuta_command_notify_progress (AnjutaCommand *self, gfloat progress)
  * of failure. 
  */
 void
-anjuta_command_set_error_message (AnjutaCommand *self, gchar *error_message)
+anjuta_command_set_error_message (AnjutaCommand *self, const gchar *error_message)
 {
-	if (self->priv->error_message)
-		g_free (error_message);
+	g_free (self->priv->error_message);
 	
 	self->priv->error_message = g_strdup (error_message);
 }
