@@ -18,8 +18,7 @@
  */
 
 #include <config.h>
-#include <gtk/gtkactiongroup.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-debug.h>
@@ -54,7 +53,7 @@ project_root_added (AnjutaPlugin *plugin,
 	
 	if (root_uri)
 	{
-		gchar *root_dir = gnome_vfs_get_local_path_from_uri (root_uri);
+		gchar *root_dir = anjuta_util_get_local_path_from_uri (root_uri);
 		if (root_dir)
 			cg_plugin->top_dir = g_strdup(root_dir);
 		else
@@ -83,7 +82,7 @@ activate_plugin (AnjutaPlugin *plugin)
 {
 	AnjutaClassGenPlugin *cg_plugin;
 	
-	DEBUG_PRINT ("AnjutaClassGenPlugin: Activating ClassGen plugin...");
+	DEBUG_PRINT ("%s", "AnjutaClassGenPlugin: Activating ClassGen plugin...");
 	cg_plugin = ANJUTA_PLUGIN_CLASS_GEN (plugin);
 	cg_plugin->prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
 	
@@ -96,16 +95,16 @@ activate_plugin (AnjutaPlugin *plugin)
 	{
 		anjuta_util_dialog_error(
 			NULL,
-			_("Could not find autogen version 5, please install the "
+			_("Could not find autogen version 5; please install the "
 			  "autogen package. You can get it from "
-			  "http://autogen.sourceforge.net"));
+			  "http://autogen.sourceforge.net."));
 
 		return FALSE;
 	}
 
 	/* set up project directory watch */
 	cg_plugin->root_watch_id = anjuta_plugin_add_watch (plugin,
-									"project_root_uri",
+									IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 									project_root_added,
 									project_root_removed, NULL);
 
@@ -117,7 +116,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 {
 	AnjutaClassGenPlugin *cg_plugin;
 	cg_plugin = ANJUTA_PLUGIN_CLASS_GEN (plugin);
-	DEBUG_PRINT ("AnjutaClassGenPlugin: Deactivating ClassGen plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaClassGenPlugin: Deactivating ClassGen plugin ...");
 	
 	/* Remove watches */
 	anjuta_plugin_remove_watch (plugin, cg_plugin->root_watch_id, TRUE);
@@ -179,61 +178,41 @@ cg_plugin_add_to_project (AnjutaClassGenPlugin *plugin,
 	IAnjutaProjectManager *manager;
 	GList *filenames;
 	GList *added_files;
-	GList *node;
-	gchar *dirname;
-	gchar *curdir;
+	GFile *file;
 	gboolean result;
 
 	manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
 	                                      IAnjutaProjectManager, NULL);
        
-	if (manager == NULL) return FALSE;
+	if (manager == NULL) 
+		return FALSE;
 
-	curdir = g_get_current_dir ();
-
-	filenames = NULL;
-	filenames = g_list_append (filenames, g_path_get_basename (header_file));
+	filenames = g_list_append (NULL, g_path_get_basename (header_file));
 	filenames = g_list_append (filenames, g_path_get_basename (source_file));
-	dirname = g_path_get_dirname (source_file);
-
-	if (dirname != NULL && strcmp (dirname, ".") != 0)
-	{
-		added_files = ianjuta_project_manager_add_sources (manager, filenames,
-														   dirname, NULL);
-	}
-	else
-	{
-		added_files = ianjuta_project_manager_add_sources (manager, filenames,
-														   curdir, NULL);
-	}
-
-	if (g_list_length (added_files) != 2)
-	{
-		for (node = added_files; node != NULL; node = g_list_next (node))
-			g_free (node->data);
-
-		result = FALSE;
-	}
-	else
-	{
-		*new_header_file = added_files->data;
-		*new_source_file = g_list_next (added_files)->data;
-
-		result = TRUE;
-	}
-
-	g_free (curdir);
-	g_free (dirname);
-	g_list_free (added_files);
+	file = g_file_new_for_path (plugin->top_dir);
+	added_files = ianjuta_project_manager_add_sources (manager, filenames,
+	                                                   file, NULL);
+	g_object_unref (file);
+	g_list_foreach (filenames, (GFunc)g_free, NULL);
 	g_list_free (filenames);
 
+	result = g_list_length (added_files) == 2;
+	if (result)
+	{
+		*new_header_file = g_file_get_path((GFile *)added_files->data);
+		*new_source_file = g_file_get_path((GFile *)g_list_next (added_files)->data);
+	}
+
+	g_list_foreach (added_files, (GFunc)g_object_unref, NULL);
+	g_list_free (added_files);
+
 	return result;
 }
 
 static void
 cg_plugin_add_to_repository (AnjutaClassGenPlugin *plugin,
-                             const gchar *header_file,
-                             const gchar *source_file)
+                             GFile *header_file,
+                             GFile *source_file)
 {
 	IAnjutaVcs *vcs;
 	vcs = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
@@ -241,8 +220,12 @@ cg_plugin_add_to_repository (AnjutaClassGenPlugin *plugin,
 
 	if(vcs != NULL)
 	{
-		ianjuta_vcs_add (vcs, header_file, NULL);
-		ianjuta_vcs_add (vcs, source_file, NULL);
+		GList* files = NULL;
+		AnjutaAsyncNotify* notify = anjuta_async_notify_new ();
+		files = g_list_append (files, header_file);
+		files = g_list_append (files, source_file);
+		ianjuta_vcs_add (vcs, files, notify, NULL);
+		g_list_free (files);
 	}
 }
 
@@ -314,16 +297,30 @@ cg_plugin_generator_created_cb (CgGenerator *generator,
 
 	loader = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
 	                                     IAnjutaFileLoader, NULL);
-
-	if (cg_window_get_add_to_repository (plugin->window))
-	{
-		cg_plugin_add_to_repository (plugin, header_file, source_file);
-	}
-
+	
 	if (cg_window_get_add_to_project (plugin->window))
 	{
-		ianjuta_file_loader_load (loader, header_file, FALSE, NULL);
-		ianjuta_file_loader_load (loader, source_file, FALSE, NULL);
+		GFile* header = g_file_new_for_path (header_file);
+		GFile* source = g_file_new_for_path (source_file);
+		IAnjutaProjectManager *manager;
+
+		ianjuta_file_loader_load (loader, header, FALSE, NULL);
+		ianjuta_file_loader_load (loader, source, FALSE, NULL);
+
+		if (cg_window_get_add_to_repository (plugin->window))
+		{
+			cg_plugin_add_to_repository (plugin, header, source);
+		}
+	
+		manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell, IAnjutaProjectManager, NULL);
+		if (manager)
+		{
+			g_signal_emit_by_name (G_OBJECT (manager), "element_added", header);
+			g_signal_emit_by_name (G_OBJECT (manager), "element_added", source);
+		}
+
+		g_object_unref (header);
+		g_object_unref (source);
 	}
 	else
 	{
@@ -345,7 +342,7 @@ cg_plugin_window_response_cb (G_GNUC_UNUSED GtkDialog *dialog,
 {
 	AnjutaClassGenPlugin *plugin;
 	IAnjutaProjectManager *manager;
-	NPWValueHeap *values;
+	GHashTable *values;
 	NPWValue *value;
 	GError *error;
 	gchar *name;
@@ -388,7 +385,7 @@ cg_plugin_window_response_cb (G_GNUC_UNUSED GtkDialog *dialog,
 				/* Use basename of the project's root URI as project name. */
 				name = g_path_get_basename (plugin->top_dir);
 				value = npw_value_heap_find_value (values, "ProjectName");
-				npw_value_heap_set_value (values, value, name, NPW_VALID_VALUE);
+				npw_value_set_value (value, name, NPW_VALID_VALUE);
 				g_free (name);
 			}
 			else
@@ -396,7 +393,7 @@ cg_plugin_window_response_cb (G_GNUC_UNUSED GtkDialog *dialog,
 				name = g_path_get_basename (cg_window_get_source_file(
 				                            plugin->window));
 				value = npw_value_heap_find_value (values, "ProjectName");
-				npw_value_heap_set_value (values, value, name, NPW_VALID_VALUE);
+				npw_value_set_value (value, name, NPW_VALID_VALUE);
 				g_free (name);
 			}
 
@@ -448,8 +445,8 @@ iwizard_activate (IAnjutaWizard *wiz, G_GNUC_UNUSED GError **err)
 	AnjutaClassGenPlugin *cg_plugin;
 	gchar *user_name;
 	gchar *user_email;
-	IAnjutaProjectManagerCapabilities caps =
-		IANJUTA_PROJECT_MANAGER_CAN_ADD_NONE;
+	IAnjutaProjectCapabilities caps =
+		IANJUTA_PROJECT_CAN_ADD_NONE;
 	
 	cg_plugin = ANJUTA_PLUGIN_CLASS_GEN (wiz);
 
@@ -482,7 +479,7 @@ iwizard_activate (IAnjutaWizard *wiz, G_GNUC_UNUSED GError **err)
 			caps = ianjuta_project_manager_get_capabilities (manager, NULL);
 	}
 
-	if((caps & IANJUTA_PROJECT_MANAGER_CAN_ADD_SOURCE) == FALSE)
+	if((caps & IANJUTA_PROJECT_CAN_ADD_SOURCE) == FALSE)
 	{
 		cg_window_set_add_to_project (cg_plugin->window, FALSE);
 		cg_window_enable_add_to_project (cg_plugin->window, FALSE);
