@@ -25,10 +25,8 @@
 #include <glib/gi18n.h>
 #include "search-box.h"
 
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkentry.h>
+#include <stdlib.h>
+#include <gtk/gtk.h>
 
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-status.h>
@@ -250,13 +248,12 @@ on_incremental_search (GtkWidget* widget, SearchBox* search_box)
 	else
 	{
 		search_start = 
-			IANJUTA_EDITOR_CELL (ianjuta_editor_get_position_iter (private->current_editor, 
-																   NULL));
+			IANJUTA_EDITOR_CELL (ianjuta_editor_get_position (private->current_editor, 
+															  NULL));
 	}
 	
-	search_end = 
-		IANJUTA_EDITOR_CELL (ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL));
-	ianjuta_iterable_last (IANJUTA_ITERABLE (search_end), NULL);
+	search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_end_position (private->current_editor, 
+																		NULL));
 	
 	if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (private->current_editor),
 									   search_text, case_sensitive,
@@ -272,7 +269,7 @@ on_incremental_search (GtkWidget* widget, SearchBox* search_box)
 		selection = IANJUTA_EDITOR_SELECTION (private->current_editor);
 		ianjuta_editor_selection_set (selection,
 									 IANJUTA_ITERABLE (result_start),
-									 IANJUTA_ITERABLE (result_end), NULL);
+									 IANJUTA_ITERABLE (result_end), TRUE, NULL);
 		g_object_unref (result_start);
 		g_object_unref (result_end);
 		
@@ -305,17 +302,24 @@ on_search_activated (GtkWidget* widget, SearchBox* search_box)
 	if (!private->current_editor || !search_text || !strlen (search_text))
 		return;
 	
-	search_start = 
-		IANJUTA_EDITOR_CELL (ianjuta_editor_get_position_iter (private->current_editor, 
-															   NULL));
+	selection = IANJUTA_EDITOR_SELECTION (private->current_editor);
+	
+	if (ianjuta_editor_selection_has_selection (selection, NULL))
+	{
+		search_start = 
+			IANJUTA_EDITOR_CELL (ianjuta_editor_selection_get_start (selection, NULL));
+	}
+	else
+	{
+		search_start = 
+			IANJUTA_EDITOR_CELL (ianjuta_editor_get_position (private->current_editor, 
+														  NULL));
+	}
 	real_start =
 			ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL);
 	
-	search_end = 
-		IANJUTA_EDITOR_CELL (ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL));
-	ianjuta_iterable_last (IANJUTA_ITERABLE (search_end), NULL);
-	
-	selection = IANJUTA_EDITOR_SELECTION (private->current_editor);
+	search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_end_position (private->current_editor, 
+																	   NULL));
 	
 	/* If a search_result is already selected, move the search start
 	 * forward by one
@@ -325,8 +329,8 @@ on_search_activated (GtkWidget* widget, SearchBox* search_box)
 	{
 		IAnjutaIterable* selection_start = 
 			ianjuta_editor_selection_get_start (selection, NULL);
-		if (ianjuta_iterable_get_position (IANJUTA_ITERABLE (search_start), NULL) ==
-			ianjuta_iterable_get_position (selection_start, NULL))
+		if (ianjuta_iterable_compare (IANJUTA_ITERABLE (search_start),
+									  selection_start, NULL) == 0)
 		{
 			gchar* selected_text =
 				ianjuta_editor_selection_get (selection, NULL);
@@ -371,18 +375,18 @@ on_search_activated (GtkWidget* widget, SearchBox* search_box)
 										   &result_start,
 										   &result_end, NULL))
 		{
-			if (ianjuta_iterable_get_position (IANJUTA_ITERABLE (result_start), NULL)
-				!= ianjuta_iterable_get_position (real_start, NULL))
+			if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_start),
+										  real_start, NULL) != 0)
 			{
 				found = TRUE;
 				anjuta_status_push (private->status, 
-									_("Search for \"%s\" reached end and was continued on top!"), search_text);
+									_("Search for \"%s\" reached the end and was continued at the top."), search_text);
 			}
 			else if (ianjuta_editor_selection_has_selection (selection, NULL))
 			{
 				anjuta_status_pop (private->status);
 				anjuta_status_push (private->status, 
-									_("Search for \"%s\" reached end and was continued on top but no new match was found!"), search_text);
+									_("Search for \"%s\" reached the end and was continued at the top but no new match was found."), search_text);
 			}				
 		}
 	}
@@ -390,7 +394,7 @@ on_search_activated (GtkWidget* widget, SearchBox* search_box)
 	{
 		ianjuta_editor_selection_set (selection,
 									  IANJUTA_ITERABLE (result_start),
-									  IANJUTA_ITERABLE (result_end), NULL);
+									  IANJUTA_ITERABLE (result_end), TRUE, NULL);
 		g_object_unref (result_start);
 		g_object_unref (result_end);
 	}
@@ -439,7 +443,7 @@ search_box_init (SearchBox *object)
 					  G_CALLBACK (on_search_focus_out),
 					  object);	
 	
-	private->case_check = gtk_check_button_new_with_label (_("Case sensitive"));
+	private->case_check = gtk_check_button_new_with_label (_("Match case"));
 	
 	private->search_button = gtk_button_new ();
 	gtk_button_set_image (GTK_BUTTON (private->search_button), search);
