@@ -33,6 +33,7 @@
 #include "git-status-command.h"
 #include "git-diff-command.h"
 #include "git-branch-list-command.h"
+#include "git-stash-list-command.h"
 
 typedef struct
 {
@@ -54,6 +55,8 @@ void git_progress_data_free (GitProgressData *data);
 void git_create_message_view (Git* plugin);
 gboolean git_check_input (GtkWidget *parent, GtkWidget *widget,  
 						  const gchar *input, const gchar *error_message);
+gboolean git_get_selected_stash (GtkTreeSelection *selection, gchar **stash);
+gboolean git_check_branches (GtkComboBox *combo_box);
 gchar *git_get_log_from_textview (GtkWidget* textview);
 guint git_status_bar_progress_pulse (Git *plugin, gchar *text);
 void git_clear_status_bar_progress_pulse (guint timer_id);
@@ -73,23 +76,38 @@ void on_git_command_progress (AnjutaCommand *command, gfloat progress,
 							  GitProgressData *data);
 void on_git_list_branch_combo_command_data_arrived (AnjutaCommand *command,
                                                     GtkListStore *branch_combo_model);
+void on_git_list_branch_command_data_arrived (AnjutaCommand *command,
+											  GtkListStore *branch_list_model);
 void on_git_list_branch_combo_command_finished (AnjutaCommand *command,
                                                 guint return_code,
                                                 GtkComboBox *combo_box);
+void on_git_list_tag_command_data_arrived (AnjutaCommand *command, 
+									   GtkListStore *tag_list_model);
+void on_git_list_stash_command_data_arrived (AnjutaCommand *command,
+											 GtkListStore *stash_list_model);
+void on_git_stash_save_command_finished (AnjutaCommand *command, 
+										 guint return_code, Git *plugin);
+void on_git_stash_apply_command_finished (AnjutaCommand *command,
+										  guint return_code, Git *plugin);
+void on_git_remote_list_command_data_arrived (AnjutaCommand *command,
+                                              GtkListStore *remote_list_model);
+void on_git_notebook_button_toggled (GtkToggleButton *toggle_button,
+                                     GtkNotebook *notebook);
 void git_select_all_status_items (GtkButton *select_all_button, 
 								  AnjutaVcsStatusTreeView *tree_view);
 void git_clear_all_status_selections (GtkButton *clear_button,
 									  AnjutaVcsStatusTreeView *tree_view);
 void on_git_origin_check_toggled (GtkToggleButton *button, GtkWidget *widget);
-
 void git_init_whole_project (Git *plugin, GtkWidget* project,
 							 gboolean active);
 void on_git_whole_project_toggled (GtkToggleButton* project, Git *plugin);
-
 void on_git_diff_command_finished (AnjutaCommand *command, guint return_code, 
 								   Git *plugin);
 void git_send_raw_command_output_to_editor (AnjutaCommand *command, 
 											IAnjutaEditor *editor);
+void git_set_log_view_column_label (GtkTextBuffer *text_buffer, 
+                                    GtkTextIter *location, 
+                                    GtkTextMark *mark, GtkLabel *column_label);
 void git_stop_status_bar_progress_pulse (AnjutaCommand *command, 
 										 guint return_code, gpointer timer_id);
 void git_hide_pulse_progress_bar (AnjutaCommand *command, guint return_code,
@@ -98,4 +116,8 @@ void git_disconnect_data_arrived_signals (AnjutaCommand *command, GObject *objec
 void git_cancel_data_arrived_signal_disconnect (AnjutaCommand *command, 
 												guint return_code,
 												GObject *signal_target);
+gboolean git_get_selected_refs (GtkTreeModel *model, GtkTreePath *path, 
+							    GtkTreeIter *iter, GList **selected_list);
+void on_git_selected_column_toggled (GtkCellRendererToggle *renderer,
+									 gchar *path, GtkListStore *list_store);
 #endif
