@@ -4,12 +4,12 @@ char *s = N_("A generic GTK+ project");
 char *s = N_("A generic GTKmm (C++) project");
 char *s = N_("A generic Xlib dock applet");
 char *s = N_("A generic Xlib project");
-char *s = N_("A generic Java project using automake project management");
+char *s = N_("A generic java project using automake project management");
 char *s = N_("A generic minimal and flat project");
-char *s = N_("A generic natively compiled Java project using the GNU Java Compiler (gcj)");
+char *s = N_("A generic natively compiled java project using the GNU Java Compiler (gcj)");
 char *s = N_("A generic project");
-char *s = N_("A generic Python project using automake project management");
-char *s = N_("A generic wxWidgets project");
+char *s = N_("A generic python project using automake project management");
+char *s = N_("A generic wx Widgets project");
 char *s = N_("A sample SDL project");
 char *s = N_("A shared or a static library project");
 char *s = N_("Add C++ support:");
@@ -26,12 +26,11 @@ char *s = N_("Author:");
 char *s = N_("Basic information");
 char *s = N_("Berkeley Software Distribution License (BSD)");
 char *s = N_("Build library as");
-char *s = N_("Comma-separated, other plugins that this plugin depends on. It could be either primary interface name or plugin location (library:class)");
+char *s = N_("Comma separated, other plugins that this plugin depends on. It could be either primary interface name or plugin location (library:class)");
 char *s = N_("Configure external packages");
 char *s = N_("Configure external packages:");
-char *s = N_("Create GtkBuilder interface file");
-char *s = N_("Create a template GtkBuilder interface file");
-char *s = N_("Create a template GtkBuilder interface file");
+char *s = N_("Create Gtk Builder interface file");
+char *s = N_("Create a template Gtk Builder interface file");
 char *s = N_("Description:");
 char *s = N_("Destination:");
 char *s = N_("Display description of the applet");
@@ -51,9 +50,9 @@ char *s = N_("Generic");
 char *s = N_("Generic (Minimal)");
 char *s = N_("Generic C++");
 char *s = N_("Generic JavaScript");
-char *s = N_("Generic gcj compiled Java");
-char *s = N_("Generic Java (automake)");
-char *s = N_("Generic Python (automake)");
+char *s = N_("Generic gcj compiled java");
+char *s = N_("Generic java (automake)");
+char *s = N_("Generic python (automake)");
 char *s = N_("Give a package name that your project require. You may also mention what is the required version of the package. For example, 'libgnomeui-2.0' or 'libgnomeui-2.0 >= 2.2.0'");
 char *s = N_("Icon File:");
 char *s = N_("Icon file for the plugin");
@@ -78,15 +77,15 @@ char *s = N_("Plugin Dependencies:");
 char *s = N_("Plugin Description:");
 char *s = N_("Plugin Title:");
 char *s = N_("Plugin class name");
-char *s = N_("Plugin has menus and/or toolbars");
+char *s = N_("Plugin has menus or/and toolbars");
 char *s = N_("Plugin interfaces to implement");
 char *s = N_("Project Name:");
-char *s = N_("Project directory, output file, etc.");
+char *s = N_("Project directory, output file etc.");
 char *s = N_("Project directory:");
-char *s = N_("Project name must not contain spaces, because it will be the name of the project build target (executable, library, etc.)");
+char *s = N_("Project name must not contain spaces, because it will be the name of the project build target (executable, library etc.)");
 char *s = N_("Project name:");
 char *s = N_("Project options");
-char *s = N_("Python web project using Django Web Framework");
+char *s = N_("Python webproject using Django Web Framework");
 char *s = N_("Require Package:");
 char *s = N_("Require SDL version:");
 char *s = N_("Require SDL_gfx library");
@@ -109,8 +108,8 @@ char *s = N_("Value Name:");
 char *s = N_("Values to watch");
 char *s = N_("Version:");
 char *s = N_("Whether the plugin has menus or toolbars");
-char *s = N_("wxWidgets");
+char *s = N_("Wx Widgets");
 char *s = N_("Xlib");
 char *s = N_("Xlib dock");
-char *s = N_("gtk-doc is used to compile API documentation for GObject-based classes");
+char *s = N_("gtk-doc is used to compile API documentations for GObject based classes");
 char *s = N_("project name");
